The original death by horse-kick data of von Bortkiewicz, with extensions and a minor correction of an apparent transcription error in the data quoted by von Bortkiewicz. The time span is extended from 1875-1894 to 1875-1907, and deaths by falling from a horse and by drowning are also included.
hkdeathsA data frame with 462 rows and 8 columns:
integer: The year of the record
factor: The army corps involved
integer: The number of regiments in the corps as given by von Bortkiewicz
integer: The number of non-commissioned officer horse-kick deaths. These were included in the total numbers and only additionally separately reported up till 1899.
integer: The number of deaths by horse-kick
integer: The number of deaths by drowning
integer: The number of deaths by falling from a horse
integer: The original (shorter) horse-kick deaths series used by von Bortkiewicz, including the transcription error